#!/usr/bin/perl
use DateTime;
use DateTime::Duration;
use DateTime::TimeZone;
use strict;

my $DIR = "/home/ATS/md110";
my $log_name = $ARGV[0];
my $timezone = `date "+%z"`;
#my $moscow_timezone = "+0400";

require "$DIR/../common.pm";

if( !$log_name )
{
    die "Log name not defined!\n";
}

my $dst_log_path = undef;
if( $log_name =~ /(\d{4})\.(\d{2})\.(\d{2})\.(\d{2})\.log/ )
{
    $dst_log_path = "$DIR/$1/$2/$3_$4";
}
else
{
    die "Incorrect log name $log_name!\n";
}

open FILE_IN, "<$DIR/source/$log_name"
		or die "Can't open $log_name on read!\n";	
open FILE_OUT, ">$dst_log_path"		    
		or die "Can't open $dst_log_path on write!\n";

M1:		    
while(<FILE_IN>)
{
    $_ =~ s/[\r\n]//g;
    $_ =~ s/^[\x00\s]+//;
    
  if ( !$_ )
  {
  	next M1;
  }
              
    
    #0709 0924 00457 63031                       68094       
    if( /^(\d{4})\s(\d{4})\s(\d{5})\s(\d+)\s(.+)$/ )
    {
	my $mmdd = $1;
	my $hhmm = $2;
	my $duration = $3;
	my $number_from = $4;
	my $tail = $5;	
	my $number_to = substr( $tail, 0, 27 );	
	my $port_to = substr( $tail, 27 );
	
	$number_to =~ s/\s//g;
	$port_to =~ s/\s//g;
	$duration =~ s/^0+//;
	
	if( !$number_to )
	{
	    print "Not found number_to: $_\n";
	    next;
	}	
	if( !$port_to )
	{
	    $port_to = "UNDEF";
	}
	
	#print "$hmm=".$hhmm."\n";
	
	my $number_from_164 = num_to_164( $number_from );
	my $number_to_164 = num_to_164( $number_to );	
	
	my $stop_time = DateTime->now( time_zone => $timezone );
	$stop_time->set( month => substr( $mmdd, 0, 2 ) );
	$stop_time->set( day => substr( $mmdd, 2 ) );
	$stop_time->set( hour => substr( $hhmm, 0, 2 ) );
	$stop_time->set( minute => substr( $hhmm, 2 ) );
	$stop_time->set( second => 0 );
	
	$stop_time->subtract( seconds => $duration );
	
	my $start_time = $stop_time->strftime( "%d.%m.%Y %H:%M:%S" );
	
	my $dst_log_record = "$start_time\t$duration\t$number_from\t$number_from_164\t$number_to\t$number_to_164\tUNDEF\t$port_to\t1\t$duration";
	print FILE_OUT "$dst_log_record\n";
    }
    else
    {
	print "Incorrect line $_!\n";
    }
}

close FILE_IN;
close FILE_OUT;

prepare_file( $log_name, $dst_log_path, $DIR );